.. _plugin-reference:

=================
Plugin Reference
=================

This section lists Plugins that currently come with WA3. Each package below
represents a particular type of extension (e.g. a workload); each sub-package of
that package is a particular instance of that extension (e.g. the Andebench
workload). Clicking on a link will show what the individual extension does,
what configuration parameters it takes, etc.

For how to implement you own Plugins, please refer to the guides in the
:ref:`writing plugins <writing-plugins>` section.

.. raw:: html

   <style>
   td {
      vertical-align: text-top;
   }
   </style>
   <table <tr><td>

.. toctree::
   :maxdepth: 2

   plugins/workloads

.. raw:: html

   </td><td>

.. toctree::
   :maxdepth: 2

   plugins/instruments

.. toctree::
   :maxdepth: 2

   plugins/energy_instrument_backends



.. raw:: html

   </td><td>

.. toctree::
   :maxdepth: 2

   plugins/output_processors

.. raw:: html

   </td><td>

.. toctree::
   :maxdepth: 2

   plugins/targets

.. raw:: html

   </td></tr></table>

